@@ -10,7 +10,7 @@ use Term::ANSIColor ();
 use Path::Class qw( file dir );
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '1.82'; # VERSION
+our $VERSION = '1.83'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -21,6 +21,7 @@ sub mvp_multivalue_args { qw(
   alien_auto_include
   alien_bin_requires
   alien_helper
+  upgrade
   
   diag
   allow_dirty ) }
@@ -186,14 +187,12 @@ sub configure
   ]);
 
   $self->add_plugins([
-    'Prereqs' => 'NeedTestMore094' => {
-      '-phase'     => 'test',
-      'Test::More' => '0.94',
+    'Author::Plicease::SpecialPrereqs' => {
+      maybe upgrade => $self->payload->{upgrade},
     },
   ]);
-  
+
   $self->add_plugins(
-    'Author::Plicease::SpecialPrereqs',
     'CPANFile',
   );
 
@@ -261,7 +260,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 1.82
+version 1.83
 
 =head1 SYNOPSIS
 
@@ -372,10 +371,6 @@ This plugin bundle is mostly equivalent to
  [Author::Plicease::MarkDownCleanup]
  travis_status = 0
  
- [Prereqs / NeedTestMore094]
- -phase = test
- Test::More = 0.94
- 
  [Author::Plicease::SpecialPrereqs]
  [CPANFile]
 
